@@ -10,7 +10,7 @@
  * Released under the GPLv3 only.\n
  * SPDX-License-Identifier: GPL-3.0-only
  *
- * @version _v1.0.17 ==== 10/06/2022_
+ * @version _v1.0.18 ==== 16/09/2022_
  */
 
 /* **********************************************************************
@@ -71,6 +71,10 @@
  * 16/04/2021	MG	1.0.15	Add print default values function.	*
  * 03/12/2021	MG	1.0.16	Tighten SPDX tag.			*
  * 10/06/2022	MG	1.0.17	Replace sprintf with safer snprintf.	*
+ * 16/09/2022	MG	1.0.18	Rename mgebuffer.h			*
+ *				Rename mgememory.h			*
+ *				Rename mgemessage.h			*
+ *				Remove unnecessary header syslog.h	*
  *									*
  ************************************************************************
  */
@@ -80,14 +84,13 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <syslog.h>
 
 #include "internal.h"
-#include <libmgec.h>
-#include <mge-errno.h>
-#include <mgebuffer.h>
-#include <mgememory.h>
-#include <mgemessage.h>
+#include <libmgec/libmgec.h>
+#include <libmgec/mge-buffer.h>
+#include <libmgec/mge-errno.h>
+#include <libmgec/mge-memory.h>
+#include <libmgec/mge-message.h>
 
 /* @cond INTERNAL */
 static struct mgemessage *get_msg(struct mgebuffer *buf,
