@@ -3,12 +3,12 @@
  *
  * Non-public errors header file. No distribution required.
  *
- * @author Copyright (C) 2018, 2019, 2021  Mark Grant
+ * @author Copyright (C) 2018, 2019, 2021, 2022  Mark Grant
  *
  * Released under the GPLv3 only.\n
  * SPDX-License-Identifier: GPL-3.0-only
  *
- * @version _v1.0.4 ==== 03/12/2021_
+ * @version _v1.0.5 ==== 16/09/2022_
  */
 
 /* **********************************************************************
@@ -21,6 +21,8 @@
  * 20/05/2018	MG	1.0.2	Add re-inclusion prevention #defines.	*
  * 08/06/2019	MG	1.0.3	clang-format coding style changes.	*
  * 03/12/2021	MG	1.0.4	Tighten SPDX tag.			*
+ * 16/09/2022	MG	1.0.5	Rename of portability.h			*
+ *				Add stddef.h for size_t.		*
  *									*
  ************************************************************************
  */
@@ -28,7 +30,9 @@
 #ifndef ERRORS_INTERNAL_H
 #define ERRORS_INTERNAL_H
 
-#include <portability.h>
+#include <libmgec/mge-portability.h>
+
+#include <stddef.h>
 
 BEGIN_C_DECLS
 
@@ -39,4 +43,3 @@ extern const size_t errno_desc_size;
 END_C_DECLS
 
 #endif /* ndef ERRORS_INTERNAL_H */
-
