@@ -5,12 +5,12 @@
  *
  * Build, manipulate and traverse functionality for singly linked lists.
  *
- * @author Copyright (C) 2016-2021  Mark Grant
+ * @author Copyright (C) 2016-2022  Mark Grant
  *
  * Released under the GPLv3 only.\n
  * SPDX-License-Identifier: GPL-3.0-only
  *
- * @version _v1.0.12 ==== 03/12/2021_
+ * @version _v1.0.13 ==== 16/09/2022_
  */
 
 /* **********************************************************************
@@ -44,6 +44,7 @@
  * 29/06/2020	MG	1.0.11	Add internal-only documentation of	*
  *				static (non-API) function.		*
  * 03/12/2021	MG	1.0.12	Tighten SPDX tag.			*
+ * 16/09/2022	MG	1.0.13	Move static function declarations here.	*
  *									*
  ************************************************************************
  */
@@ -53,9 +54,10 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include "sllist-internal.h"
-#include <mge-errno.h>
-#include <sllist.h>
+#include <libmgec/mge-errno.h>
+#include <libmgec/sllist.h>
+
+static void free_sll_node(struct sllistnode *currentnode);
 
 /**
  * Add a node to the start of the singly linked list.
@@ -205,4 +207,3 @@ static void free_sll_node(struct sllistnode *focus)
 	free(focus);
 }
 /* @endcond */
-
