@@ -5,12 +5,12 @@
  *
  * Standard library-wide software versioning functions and information.
  *
- * @author Copyright (C) 2015-2019, 2021  Mark Grant
+ * @author Copyright (C) 2015-2019, 2021, 2022  Mark Grant
  *
  * Released under the GPLv3 only.\n
  * SPDX-License-Identifier: GPL-3.0-only
  *
- * @version _v1.0.7 ==== 04/12/2021_
+ * @version _v1.0.8 ==== 16/09/2022_
  */
 
 /* **********************************************************************
@@ -27,15 +27,15 @@
  *				AC_DEFINE'd value in config.h		*
  * 11/06/2019	MG	1.0.6	clang-format coding style changes.	*
  * 04/12/2021	MG	1.0.7	Tighten SPDX tag.			*
+ * 16/09/2022	MG	1.0.8	Remove unnecessary header stdlib.h	*
  *									*
  ************************************************************************
  */
 
 #include <config.h>
 #include <stdio.h>
-#include <stdlib.h>
 
-#include <libmgec.h>
+#include <libmgec/libmgec.h>
 
 /**
  * Get the git-describe based package version.
@@ -70,4 +70,3 @@ void libmgec_print_src_version(void)
 {
 	printf("%s %s %s", "libmgec Source version -", SOURCE_VERSION, "\n");
 }
-
